@@ -174,9 +174,6 @@ def idx2series(idx):
 def df2msg(df, labels=None, index_cols=None):
     indices = None
     if index_cols is not None:
-        # if there is already an index set, we want to preserve it.
-        if not (type(df.index) == pd.RangeIndex and df.index.name is None):
-            df.reset_index(inplace=True)
         indices = [series2col(df[name], name) for name in index_cols]
         cols = [col for col in df.columns if col not in index_cols]
         df = df[cols]
@@ -230,11 +227,8 @@ def series2col_with_dtype(s, name, dtype):
         kw['bools'] = s
         kw['dtype'] = fpb.BOOLEAN
     elif dtype == fpb.TIME:
-        if s.dt.tz:
-            try:
-                s = s.dt.tz_localize(pytz.UTC)
-            except TypeError:
-                s = s.dt.tz_convert('UTC')
+        s = pd.to_datetime(s, utc=True)
+        s = s.dt.tz_convert('UTC')
         kw['times'] = s.astype(np.int64)
         kw['dtype'] = fpb.TIME
     elif dtype == fpb.NULL:
@@ -337,7 +331,7 @@ def get_empty_value_by_type(dtype):
     elif dtype == fpb.STRING:
         return ''
     elif dtype == fpb.TIME:
-        return datetime.fromtimestamp(0)
+        return datetime.fromtimestamp(0, pytz.UTC)
     elif dtype == fpb.BOOLEAN:
         return False
     elif dtype == fpb.NULL:
@@ -370,6 +364,14 @@ def get_actual_types(df):
                     column_types[col.name] = fpb.BOOLEAN
                     has_data = True
                     break
+                if isinstance(x, pd.Timestamp):
+                    column_types[col.name] = fpb.TIME
+                    has_data = True
+                    break
+                if isinstance(x, datetime):
+                    column_types[col.name] = fpb.TIME
+                    has_data = True
+                    break
                 raise WriteError('{} - contains an unsupported value type - {}'
                                  .format(col_name, type(x)))
             # If all items in the column are None
